@@ -21,9 +21,9 @@ $ notdb [filename] --password
 
 '''
 
-from .ndb import NotDBClient, UTypes, checkTypes
+from .ndb import NotDBClient, UTypes, create_db, get_password, schema
 from .errors import *
 
-__version__ = '1.0.2'
+__version__ = '1.1.0'
 __all__ = ['InvalidDictError', 'InvalidHostError', 'NotDBClient', 'UTypes', 'WrongPasswordError',
             'checkTypes', '__version__']
\ No newline at end of file
